@@ -9,7 +9,6 @@ import time
 import sched
 from datetime import datetime
 from datetime import timedelta
-# from tabdeal.apm.commons import ReportType, BatchCommandType
 
 import requests
 import traceback
@@ -102,12 +101,10 @@ def send_to_server(s, content_type):
             return False
 
         if result.status_code != 200:
-            with open('apm_log.txt', 'a') as f:
-                f.write(f"{result.status_code}\n")
+            log_error(f"{result.status_code}")
         return result.status_code == 200
     except:
-        with open('apm_log.txt', 'a') as f:
-            f.write(f'In send_to_server\n{traceback.format_exc()}\n')
+        log_error(f'In send_to_server\n{traceback.format_exc()}')
         return False
 
 
@@ -387,8 +384,6 @@ class AggregationDelayHandler:
 class CoreAgent:
     _instance = None
 
-    port = 0
-    host = ''
     log_level = ''
 
     timer_started = False
@@ -408,7 +403,7 @@ class CoreAgent:
     max_failed_retry = 5
 
     @classmethod
-    def run(cls, host, port):
+    def run(cls, host='localhost', port=6591):
         try:
             cls.sock.bind((host, port))
             # logger.error(f'Bind successful {os.getpid()}')
@@ -463,9 +458,6 @@ class CoreAgent:
                     recv = conn.recv(remaining_size)
                     data += recv
                     remaining_size -= len(recv)
-                # logger.error(f"{str(size)} to unpack, cur len: {len(data)}")
-                with open('what.txt', 'wb') as f:
-                    f.write(data)
                 data = data.decode('utf-8')
                 parsed = get_parsed_message(data)
                 result_type, result = parsed.result_type, parsed.result
@@ -514,21 +506,11 @@ class CoreAgent:
                 result = send_to_server(failed_submission,
                                         content_type=ReportType.Endpoint.value)
                 if result:
-                    with open('upload_log.txt', 'a') as f:
-                        # f.write(
-                        #     f"SUCCESS RETRY {datetime.now()} {failed_submission[list(failed_submission.keys())[0]]['start_time']}\n")
-                        f.write(
-                            f"SUCCESS RETRY {datetime.now()}\n")
                     cls.failed_submissions.pop(i)
                 else:
-                    with open('upload_log.txt', 'a') as f:
-                        # f.write(
-                        #     f"FAIL RETRY {datetime.now()} {failed_submission[list(failed_submission.keys())[0]]['start_time']}\n")
-                        f.write(
-                            f"FAIL RETRY {datetime.now()}\n")
+                    log_error(f"FAIL RETRY {datetime.now()}")
         except:
-            with open('failed_submission.txt', 'a') as f:
-                f.write(f"{datetime.now()}\n{traceback.format_exc()}\n\n")
+            log_error(f"{datetime.now()}\n{traceback.format_exc()}")
 
         cls.data_lock.acquire()
         for key in cls.endpoints_aggregate_data.keys():
@@ -540,13 +522,9 @@ class CoreAgent:
                     # logger.error(data_to_send)
                     result = send_to_server(data_to_send,
                                             content_type=ReportType.Endpoint.value)
-                    if result:
-                        with open('upload_log.txt', 'a') as f:
-                            f.write(f"SUCCESS {datetime.now()} {window} {cls.endpoints_aggregate_data[key][window].get_dict()['num_operations']}\n")
-                    else:
+                    if not result:
                         cls.failed_submissions.append(data_to_send)
-                        with open('upload_log.txt', 'a') as f:
-                            f.write(f"Fail {datetime.now()} {window} {cls.endpoints_aggregate_data[key][window].get_dict()['num_operations']}\n")
+                        log_error(f"Fail {datetime.now()} {window} {cls.endpoints_aggregate_data[key][window].get_dict()['num_operations']}")
                     cls.endpoints_aggregate_data[key].pop(window)
             except:
                 logger.error(traceback.format_exc())
@@ -565,15 +543,9 @@ class CoreAgent:
                     data_to_send = {'BatchReportTasks': cls.tasks_aggregate_data[key][window].get_dict()}
                     result = send_to_server(data_to_send,
                                             content_type=ReportType.Task.value)
-                    if result:
-                        with open('upload_log.txt', 'a') as f:
-                            f.write(
-                                f"SUCCESS {datetime.now()} {window} {cls.tasks_aggregate_data[key][window].get_dict()['num_operations']}\n")
-                    else:
+                    if not result:
                         cls.failed_submissions.append(data_to_send)
-                        with open('upload_log.txt', 'a') as f:
-                            f.write(
-                                f"Fail {datetime.now()} {window} {cls.tasks_aggregate_data[key][window].get_dict()['num_operations']}\n")
+                        log_error(f"Fail {datetime.now()} {window} {cls.tasks_aggregate_data[key][window].get_dict()['num_operations']}")
                     cls.tasks_aggregate_data[key].pop(window)
 
             except:
